==> haskell-xcb-types-0.9.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xcb-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcb-types
version: 0.9.0
id: xcb-types-0.9.0-CyYzUqjRd3RBheFgqQW3b
key: xcb-types-0.9.0-CyYzUqjRd3RBheFgqQW3b
license: BSD-3-Clause
maintainer: Antoine Latter <aslatter@gmail.com>
author: Antoine Latter
homepage: http://community.haskell.org/~aslatter/code/xcb-types
synopsis: Parses XML files used by the XCB project
description:
    This package provides types which mirror the structures
    used in the XCB code generation XML files.
    .
    See project http://xcb.freedesktop.org/ for more information about the XCB
    project.
    .
    The XML files describe the data-types, events and requests used by the
    X Protocol, and are used to auto-generate large parts of the XCB project.
    .
    This package parses these XML files into Haskell data structures.
    .
    If you want to do something with these XML descriptions but don'\''t want
    to learn XSLT, this package should help.
    .
    This version of xcb-types is intended to fully parse the X Protocol
    description version 1.4.
category: Data
abi: 62054bcbab801f0eb43c3f403c1341f6
exposed: True
exposed-modules:
    Data.XCB Data.XCB.FromXML Data.XCB.Pretty Data.XCB.Types
hidden-modules: Data.XCB.Utils
import-dirs: /usr/lib/ghc-8.6.3/site-local/xcb-types-0.9.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/xcb-types-0.9.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/xcb-types-0.9.0
hs-libraries: HSxcb-types-0.9.0-CyYzUqjRd3RBheFgqQW3b
depends:
    base-4.12.0.0 containers-0.6.0.1 mtl-2.2.2 pretty-1.1.3.6
    xml-1.3.14-ESp8cJy4XJ8BJKfvGeNymT
haddock-interfaces: /usr/share/doc/haskell-xcb-types/html/xcb-types.haddock
haddock-html: /usr/share/doc/haskell-xcb-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xcb-types-0.10.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xcb-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xcb-types
version: 0.10.0
id: xcb-types-0.10.0-LAPkEAFk1M02nxYyKVKkJ0
key: xcb-types-0.10.0-LAPkEAFk1M02nxYyKVKkJ0
license: BSD-3-Clause
maintainer: Antoine Latter <aslatter@gmail.com>
author: Antoine Latter
homepage: http://community.haskell.org/~aslatter/code/xcb-types
synopsis: Parses XML files used by the XCB project
description:
    This package provides types which mirror the structures
    used in the XCB code generation XML files.
    .
    See project http://xcb.freedesktop.org/ for more information about the XCB
    project.
    .
    The XML files describe the data-types, events and requests used by the
    X Protocol, and are used to auto-generate large parts of the XCB project.
    .
    This package parses these XML files into Haskell data structures.
    .
    If you want to do something with these XML descriptions but don'\''t want
    to learn XSLT, this package should help.
    .
    This version of xcb-types is intended to fully parse the X Protocol
    description version 1.13.
category: Data
abi: 5afb7f64db3719726fa9a68ccb68a5e5
exposed: True
exposed-modules:
    Data.XCB Data.XCB.FromXML Data.XCB.Pretty Data.XCB.Types
hidden-modules: Data.XCB.Utils
import-dirs: /usr/lib/ghc-8.6.3/site-local/xcb-types-0.10.0
library-dirs: /usr/lib/ghc-8.6.3/site-local/xcb-types-0.10.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/xcb-types-0.10.0
hs-libraries: HSxcb-types-0.10.0-LAPkEAFk1M02nxYyKVKkJ0
depends:
    base-4.12.0.0 containers-0.6.0.1 mtl-2.2.2 pretty-1.1.3.6
    xml-1.3.14-ESp8cJy4XJ8BJKfvGeNymT
haddock-interfaces: /usr/share/doc/haskell-xcb-types/html/xcb-types.haddock
haddock-html: /usr/share/doc/haskell-xcb-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
